*******
History
*******


v{{ cookiecutter.version }} ({% now 'local' %})
===============================================

Development start:
This package was created with `micc <https://github.com/etijskens/micc>`_,
using the project template
`micc/micc-module <https://github.com/audreyr/cookiecutter-pypackage>`_.
